package config

import (
	"database/sql"
	"fmt"
	"gopkg.in/ini.v1"
	"log"
	"os"
	"shandong_datapush/common"
	_ "github.com/denisenkom/go-mssqldb"
	_ "github.com/lib/pq"
    _ "github.com/go-sql-driver/mysql"
)

var (
	DBType string
	DBConnInfo *common.DBConnectInfo
	TailPond *common.TailPondInfor
	StaticSql *common.StaticSqlLanguage
	RealTimeSql *common.RealTimeSqlLanguage
	DB *sql.DB
    err error
)

func init() {
	file, err := ini.Load("./config/conf.ini")
	common.ErrorPrintln("读取配置文件异常", err)
	DBType = file.Section("databaseType").Key("type").String()
	DBConnInfo = new(common.DBConnectInfo)
	_ = file.Section("databaseConnection").MapTo(DBConnInfo)
	TailPond = new(common.TailPondInfor)
	_ = file.Section("wkkBasicInfo").MapTo(TailPond)
	StaticSql = new(common.StaticSqlLanguage)
	_ = file.Section("StaticSqlLanguage").MapTo(StaticSql)
	RealTimeSql = new(common.RealTimeSqlLanguage)
	_ = file.Section("RealTimeSqlLanguage").MapTo(RealTimeSql)
	common.ErrorPrintln("数据库连接信息映射异常", err)
	f, err := os.OpenFile("test.txt", os.O_CREATE|os.O_APPEND|os.O_WRONLY, 0666)
	common.ErrorPrintln("日志文件创建失败", err)
	log.SetOutput(f)
}

func DBConnection() {
	if DBType == "postgresql" {
		log.Println("当前使用pg数据库")
		connString := fmt.Sprintf("host=%s port=%s user=%s password=%s dbname=%s sslmode=disable",DBConnInfo.Server, DBConnInfo.Port, DBConnInfo.Username, DBConnInfo.Password, DBConnInfo.DBName)
		DB, err = sql.Open("postgres", connString)
		common.ErrorPrintln("postgres数据库连接异常" , err)
		err = DB.Ping()
		if err != nil {
			log.Fatalf("[Error] PG 数据库连接失败: %s", err.Error())
		}else {
			log.Println("postgres 数据库连接成功！")
		}
	} else if DBType == "sqlserver" {
		log.Println("当前使用sqlserver数据库")
		connString := fmt.Sprintf("server=%s;database=%s;user id=%s;password=%s;port=%s;encrypt=disable", DBConnInfo.Server, DBConnInfo.DBName, DBConnInfo.Username, DBConnInfo.Password, DBConnInfo.Port)
		DB, err = sql.Open("mssql", connString)
		common.ErrorPrintln("sqlserver数据库连接异常" , err)
		err = DB.Ping()
		if err != nil {
			log.Fatalf("[Error] sqlserver 数据库连接失败: %s", err.Error())
		}else {
			log.Println("sqlserver 数据库连接成功！")
		}
	} else if DBType == "mysql" {
		log.Println("当前使用mysql数据库")
		connString := fmt.Sprintf("%s:%s@tcp(%s:%s)/%s?charset=utf8", DBConnInfo.Username, DBConnInfo.Password, DBConnInfo.Server, DBConnInfo.Port, DBConnInfo.DBName)
		DB, err = sql.Open("mysql", connString)
		common.ErrorPrintln("mysql数据库连接异常" , err)
		err = DB.Ping()
		if err != nil {
			log.Fatalf("[Error] mysql 数据库连接失败: %s", err.Error())
		}else {
			log.Println("mysql 数据库连接成功！")
		}
	}
}